$wnd.rstudio.runAsyncCallback3("function cpq(a){this.a=a}\nfunction epq(a){this.a=a}\nfunction npq(a){this.a=a}\nfunction pCf(a,b){var c;for(c=0;c<a.s.a.length;c++){if(S6d(a.s,c).lOc==b){nIf(a.u,IBe(c));break}}}\nfunction _oq(a){var b;b=apq(a,(Yoq(),Xoq).c8b(),a.b,dwp(a.c.c));b||apq(a,Xoq.$7b(),a.a,bwp(a.c.c))}\nfunction bpq(a,b){this.c=a;this.b=dwp(a.c).oYb();this.a=bwp(a.c).oYb();xi(b,new cpq(this),dE?dE:(dE=new yB))}\nfunction Zoq(a,b,c){var d;d=Nhq(a.b.a);uCf(d,S4p(N4j((NLh(),MLh).a)));!!b&&pCf(d,b);ACf(d,c);rof(d,true);new bpq(a,d);(oTh()||!!$wnd.remoteDesktop)&&xTh()}\nfunction apq(a,b,c,d){if(gO(c)!==gO(d.oYb())&&gO(d.$s())!==gO(d.oYb())){F2e(2,(Yoq(),Xoq)._7b(),Xoq.a8b(b,d.oYb(),d.$s()),new epq(a),true);return true}else{return false}}\nfunction jpq(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=Nxq(a.a.b.a));switch(a.c){case 1:Zoq(a.a.a,null,true);break;case 2:Zoq(a.a.a,a.b[0],mAe(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].mn()}}\nvar jOB='LaTeX typesetting',kOB='Project Option Unchanged',lOB='You changed the global option for ',mOB=', however the current project is still configured to use ',nOB='weaving Rnw files';SNd(2996,1,{},bpq);var hfc=JAe(2996);SNd(2997,1,mEy,cpq);_.xo=function dpq(a){_oq(this.a)};var ffc=JAe(2997);SNd(2998,1,lKy,epq);_.mn=function fpq(){x9e(this.a.c.a.lh)};var gfc=JAe(2998);SNd(638,1,Tez);_.kn=function mpq(){jpq((new npq(this)).a)};SNd(3063,1,LGy,npq);_.mn=function opq(){jpq(this.a)};var ifc=JAe(3063);SNd(4145,1,z$A);_.$7b=function kuq(){return jOB};_._7b=function luq(){return kOB};_.a8b=function muq(a,b,c){return lOB+a+hGy+b+mOB+c+'.\\\\n\\\\nDo you want to edit the options for the current project as well?'};_.c8b=function ouq(){return nOB};SNd(4146,1,z$A);_.$7b=function wuq(){return jOB};_._7b=function xuq(){return kOB};_.a8b=function yuq(a,b,c){return lOB+a+hGy+b+mOB+c+'.\\n\\nDo you want to edit the options for the current project as well?'};_.c8b=function Auq(){return nOB};SNd(4144,1,z$A);_.$7b=function Iuq(){return 'Mise en page LaTeX'};_._7b=function Juq(){return 'Option du projet inchang\\xE9e'};_.a8b=function Kuq(a,b,c){return \"Vous avez chang\\xE9 l'option globale de \"+a+' en '+b+', mais le projet actuel est toujours configur\\xE9 pour utiliser '+c+'.\\n\\nVoulez-vous \\xE9galement modifier les options du projet actuel ?'};_.c8b=function Muq(){return 'Tisse le fichiers Rnw'};Dqy(hm)(3);\n//# sourceURL=rstudio-3.js\n")
