$wnd.rstudio.runAsyncCallback9("function Rus(a){this.a=a}\nfunction yss(a){a.K.M7b();AZg(a.k.p)}\nfunction wss(a){Nuq(a.k);Zyi(a.a,nss.Xjc(),'loadhistory')}\nfunction xss(a){Nuq(a.k);czi(a.a,nss._jc(),'.Rhistory',false,'savehistory')}\nfunction Nus(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=uvs(a.a.b.a);Qnq(a.a,a.a.a)}switch(a.c){case 1:a.a.a.K.K7b();break;case 2:a.a.a.K.L7b();break;case 3:wss(a.a.a);break;case 4:xss(a.a.a);break;case 5:yss(a.a.a);break;case 6:a.a.a.K.N7b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].mn()}}\nvar lPB='Load History',mPB='Save History As';SNd(4031,1,TdB);_.Xjc=function Bts(){return lPB};_._jc=function Fts(){return mPB};SNd(4030,1,TdB);_.Xjc=function Wts(){return lPB};_._jc=function $ts(){return mPB};SNd(4029,1,TdB);_.Xjc=function pus(){return \"Chargement de l'historique\"};_._jc=function tus(){return \"Enregistrer l'historique en tant que\"};SNd(517,1,Tez);_.kn=function Qus(){Nus((new Rus(this)).a)};SNd(7405,1,LGy,Rus);_.mn=function Sus(){Nus(this.a)};var DCc=JAe(7405);Dqy(hm)(9);\n//# sourceURL=rstudio-9.js\n")
