$wnd.rstudio.runAsyncCallback16("function zRt(a){this.a=a}\nfunction ROt(a,b){this.a=a;this.b=b;Rmf.call(this)}\nfunction tOt(a,b){a.a=b;NQt(a.q,pOt(a,null),a.a.file_path)}\nfunction vOt(a,b){b.slide_index==0&&Nuq(a.q);a.a=b;NQt(a.q,pOt(a,null),a.a.file_path)}\nfunction COt(a){nph(nOt.Hqc(),Roe());_2h(a.c,new W4h,false)}\nfunction qOt(a){var b;b=AAi(new BAi(0,nOt.Dqc()));mym(a.o,new ROt(a,b))}\nfunction mym(a,b){pDm(a,Tvz,'close_presentation_pane',new xL,b)}\nfunction BOt(a){var b;a.K.M7b();!!a.a&&a.a.active&&(b=Rjf(Oh(a.q.d).contentWindow),!(!tCe(vKy,b)&&!tCe('javascript:void(0)',b)))&&tOt(a,a.a)}\nfunction vRt(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=jSt(a.a.b.a);Qnq(a.a,a.a.a)}switch(a.c){case 1:qOt((c=a.a.a,a.b[0],c));break;case 2:vOt(a.a.a,a.b[0]);break;case 3:a.a.a.K.K7b();break;case 4:a.a.a.K.L7b();break;case 5:BOt(a.a.a);break;case 6:COt((b=a.a.a,a.b[0],b));break;case 7:a.a.a.K.N7b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].mn()}}\nvar oRB='Closing Presentation...',pRB='Opening Presentation...';SNd(8217,33,{},ROt);_.BA=function TOt(a){var b;_2h((b=this,a,b).a.c,new W4h,false)};_.AA=function SOt(a){Qzi(this.b,a.a?a.a.c:a.d)};var MRc=JAe(8217);SNd(9087,1,VmB);_.Dqc=function wPt(){return oRB};_.Hqc=function BPt(){return pRB};SNd(9085,1,VmB);_.Dqc=function OPt(){return oRB};_.Hqc=function TPt(){return pRB};SNd(9086,1,VmB);_.Dqc=function eQt(){return 'Fermeture de la pr\\xE9sentation...'};_.Hqc=function jQt(){return 'Ouvrir la pr\\xE9sentation...'};SNd(466,1,Tez);_.kn=function yRt(){vRt((new zRt(this)).a)};SNd(7486,1,LGy,zRt);_.mn=function ARt(){vRt(this.a)};var mSc=JAe(7486);Dqy(hm)(16);\n//# sourceURL=rstudio-16.js\n")
