$wnd.rstudio.runAsyncCallback7("function hft(a){this.a=a}\nfunction ket(a,b){this.a=a;this.b=b}\nfunction fet(a,b){b==null?uaf(a,det.zmc()):uaf(a,b)}\nfunction zet(a,b){yi(a.d,new elf(false));pet(a.d,b,0)}\nfunction QBm(a,b){pDm(a,Tvz,'markers_tab_closed',new xL,b)}\nfunction het(a,b){var c,d,e,f,g,h,i;d=a.s;zie(d.p);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new ket(a,f);e=new aQd($Pd(new _Pd,f).a.a);Vkh(d,new Rje(e,c))}}\nfunction pet(a,b,c){var d;gIj(a.b);fet(a.c,null);het(a.c,nN(hN(c1,1),mry,2,6,[]));if(b.markers){d=b.markers;kIj(a.b,null,d.base_path,d.markers,c,false);het(a.c,Dyf(b.names));fet(a.c,d.name)}}\nfunction yet(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){yi(a.d,new elf(true));pet(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=QHj(d));!!f&&paj(a.b,wnf(f.path),p1e(f.line,f.column),false)}}}else{yi(a.d,new Zkf)}}\nfunction dft(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=qft(a.a.b.a);Qnq(a.a,a.a.a)}switch(a.c){case 1:xet(a.a.a);break;case 2:a.a.a.K.K7b();break;case 3:a.a.a.K.L7b();break;case 4:QBm(a.a.a.c,new ROh);break;case 5:yet(a.a.a,a.b[0]);break;case 6:a.a.a.K.M7b();break;case 7:a.a.a.K.N7b();break;case 8:zet(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].mn()}}\nSNd(9102,1,fty,ket);_.mn=function met(){yE(this.a,this.b)};var $Kc=JAe(9102);SNd(441,1,Tez);_.kn=function gft(){dft((new hft(this)).a)};SNd(7243,1,LGy,hft);_.mn=function ift(){dft(this.a)};var lLc=JAe(7243);Dqy(hm)(7);\n//# sourceURL=rstudio-7.js\n")
